@@ -187,7 +187,7 @@ static int counter;
 static int xdead, ydead, isdead, countdead;
 static int roto_speed;
 
-/*************** The Factor and Faraction Activiy game Functions ***************/
+/*************** The Factor and Fraction Activity Game Functions ***************/
 
 /* Local function prototypes: */
 
@@ -234,9 +234,7 @@ void factors(void)
   counter = 0;
   tux_img = IMG_TUX_CONSOLE1;
 
-  #ifdef TUXMATH_DEBUG
-     fprintf(stderr, "Entering factors():\n");
-  #endif
+  DEBUGMSG(debug_factoroids, "Entering factors():\n");
 
   FF_game = FACTOROIDS_GAME;
   
@@ -316,11 +314,7 @@ void fractions(void)
   counter = 0;
   tux_img = IMG_TUX_CONSOLE1;
 
-  
-  #ifdef TUXMATH_DEBUG
-     fprintf(stderr, "Entering factors():\n");
-  #endif
-  
+  DEBUGMSG(debug_factoroids, "Entering factors():\n");
   /*****Initalizing the Factor activiy *****/
   FF_game = FRACTIONS_GAME;
 
@@ -403,9 +397,10 @@ static int FF_init(void)
   if(screen->h < 600 && screen->w < 800)
     zoom = 0.65;
   else
-    zoom=(float)screen->w/(float)BASE_RES_X;
+    zoom = (float)screen->w/(float)BASE_RES_X;
 
-  printf("The zoome rate is: %f\n", zoom);
+  DEBUGCODE(debug_factoroids)
+    printf("The zoom factor is: %f\n", zoom);
 
   /*************** Precalculating software rotation ***************/
 
@@ -492,7 +487,7 @@ static int FF_init(void)
   shift_pressed = 0;
   shoot_pressed = 0;
 
-  score = 1;
+  score = 0;
   wave = 0;
   xdead = 0;
   ydead = 0;
@@ -1230,9 +1225,6 @@ static int FF_over(int game_status)
   SDL_Rect dest_message;
   SDL_Event event;
 
-#ifdef TUXMATH_DEBUG
-  //print_exit_conditions();
-#endif
 
   /* TODO: need better "victory" screen with animation, special music, etc., */
   /* as well as options to review missed questions, play again using missed  */
@@ -1286,9 +1278,7 @@ static int FF_over(int game_status)
 
     case GAME_OVER_ERROR:
     {
-#ifdef TUXMATH_DEBUG
-      printf("\ngame() exiting with error");
-#endif
+      DEBUGMSG(debug_factoroids, "game() exiting with error");
     }
     case GAME_OVER_LOST:
     case GAME_OVER_OTHER:
@@ -1466,7 +1456,7 @@ int fast_sin(int angle)
 /*Return -1 if no laser is available*/
 int FF_add_laser(void)
 {
-  int i, k, zapIndex;
+  int i, k, zapIndex, zapScore;
   float ux, uy, s, smin,dx,dy,dx2, dy2, d2, thresh;
   int screensize;
   SDL_Surface *asteroid_image;
@@ -1502,7 +1492,10 @@ int FF_add_laser(void)
       // With this parametrization, it's easy to calculate the
       // closest approach to the asteroid center, etc.
       zapIndex = -1;  // keep track of the closest "hit" asteroid
+      zapScore = 0;
       smin = 10*screensize;
+      
+
       for (k=0; k<MAX_ASTEROIDS; k++)
       {
 	if (!asteroid[k].alive)
@@ -1524,16 +1517,30 @@ int FF_add_laser(void)
 	  {
 	    // The laser intersects the asteroid. Check to see if
 	    // the answer works
-	    if((asteroid[k].isprime && ((num==asteroid[k].fact_number)||(num==0))) ||
-	       (FF_game==FACTOROIDS_GAME && num > 1 && ((asteroid[k].fact_number%num)==0) && (num!=asteroid[k].fact_number)) ||
-	       (FF_game==FRACTIONS_GAME && num > 1 && ((asteroid[k].a%num)==0) && ((asteroid[k].a%num)==0) && (num!=asteroid[k].fact_number)))
+
+	    if( (FF_game==FACTOROIDS_GAME && (asteroid[k].isprime && ((num==asteroid[k].fact_number)||(num==0)))) ||
+		(FF_game==FRACTIONS_GAME && (asteroid[k].isprime && num==0))
+	    ) 
 	    {
 	      // It's valid, check to see if it's closest
 	      if (s < smin)
 	      {
-		// It's the closest yet examined
+		// It's the closest yet examined but has not score
 		smin = s;
 		zapIndex = k;
+		zapScore = 0;
+	      }
+	    }
+	    else if((FF_game==FACTOROIDS_GAME && num > 1 && ((asteroid[k].fact_number%num)==0) && (num!=asteroid[k].fact_number)) ||
+	       (FF_game==FRACTIONS_GAME && num > 1 && ((asteroid[k].a%num)==0) && ((asteroid[k].b%num)==0) && (num!=asteroid[k].fact_number)))
+	    {
+	      // It's valid, check to see if it's closest
+	      if (s < smin)
+	      {
+		// It's the closest yet examined and has socre
+		smin = s;
+		zapIndex = k;
+		zapScore = 1;
 	      }
 	    }
 	  }
@@ -1551,7 +1558,10 @@ int FF_add_laser(void)
 
 	if (floor((float)score/100) < floor((float)(score+num)/100))
 	  tuxship.lives++;
-	score += num;
+	if(zapScore)
+	{
+	    score += num;
+	}
       }
       return 1;
     }
@@ -1713,9 +1723,7 @@ void FF_ShowMessage(char* str1, char* str2, char* str3, char* str4)
 
   s1 = s2 = s3 = s4 = NULL;
 
-#ifdef TUXMATH_DEBUG
-  fprintf(stderr, "ShowMessage() - creating text\n" );
-#endif
+  DEBUGMSG(debug_factoroids, "ShowMessage() - creating text\n" );
 
   if (str1)
     s1 = BlackOutline(str1, DEFAULT_MENU_FONT_SIZE, &white);
@@ -1727,10 +1735,7 @@ void FF_ShowMessage(char* str1, char* str2, char* str3, char* str4)
   if (str4)
     s4 = BlackOutline(str4, DEFAULT_MENU_FONT_SIZE, &white);
 
-#ifdef TUXMATH_DEBUG
-  fprintf(stderr, "ShowMessage() - drawing screen\n" );
-#endif
-
+  DEBUGMSG(debug_factoroids, "ShowMessage() - drawing screen\n" );
 
   /* Draw lines of text (do after drawing Tux so text is in front): */
   if (s1)
@@ -2170,7 +2175,7 @@ static int check_exit_conditions(void)
   {
     return GAME_OVER_LOST;
   }
-  if(score>=10000 || wave >= 30 )
+  if(score>=19999 || wave >= 20 )
   {
     return GAME_OVER_WON;
   }
@@ -2202,10 +2207,6 @@ static int check_exit_conditions(void)
   /* This SHOULD NOT HAPPEN and means we have a bug somewhere. */
  /* if (!MC_ListQuestionsLeft() && !num_comets_alive)
   {
-    #ifdef TUXMATH_DEBUG
-    printf("\nListQuestionsLeft() = %d", MC_ListQuestionsLeft());
-    printf("\nnum_comets_alive = %d", num_comets_alive);
-    #endif 
     return GAME_OVER_ERROR;
   }
   */
