@@ -4,7 +4,7 @@
 * Description: Implementation of high score tables for tuxmath.
 *
 *
-* Author: David Bruce <dbruce@tampabay.rr.com>, (C) 2007
+* Author: David Bruce <davidstuartbruce@gmail.com>, (C) 2007
 *
 * Copyright: See COPYING file that comes with this distribution
 * (Briefly, GNU GPL version 2 or greater).
@@ -13,12 +13,16 @@
 
 #include "tuxmath.h"
 #include "highscore.h"
+#include "menu.h"
 #include "titlescreen.h"
 #include "fileops.h"
 #include "setup.h"
 #include "options.h"
 #include "SDL_extras.h"
 #include "convert_utf.h"
+#include "transtruct.h"
+#include "network.h"
+#include "throttle.h"
 
 
 typedef struct high_score_entry {
@@ -38,7 +42,6 @@ void DisplayHighScores(int level)
 {
   int i = 0;
   int finished = 0;
-  int tux_frame = 0;
   Uint32 frame = 0;
   Uint32 start = 0;
 
@@ -51,61 +54,20 @@ void DisplayHighScores(int level)
   char score_strings[HIGH_SCORES_SAVED][HIGH_SCORE_NAME_LENGTH + 10] = {{'\0'}};
 
   SDL_Rect score_rects[HIGH_SCORES_SAVED];
-  SDL_Rect leftRect, rightRect, stopRect, TuxRect, table_bg;
-
+  SDL_Rect table_bg;
 
   const int max_width = 300;
   int score_table_y = 100;
 
-  sprite* Tux = LoadSprite("tux/bigtux", IMG_ALPHA);
   const int title_font_size = 32;
   const int player_font_size = 14;
 
-
-  /* --- Set up the rects for drawing various things: ----------- */
-
-  /* Put arrow buttons in right lower corner, inset by 20 pixels */
-  /* with a 10 pixel space between:                              */
-  if (images[IMG_RIGHT])
-  {
-    rightRect.w = images[IMG_RIGHT]->w;
-    rightRect.h = images[IMG_RIGHT]->h;
-    rightRect.x = screen->w - images[IMG_RIGHT]->w - 20;
-    rightRect.y = screen->h - images[IMG_RIGHT]->h - 20;
-  }
-
-  if (images[IMG_LEFT])
-  {
-    leftRect.w = images[IMG_LEFT]->w;
-    leftRect.h = images[IMG_LEFT]->h;
-    leftRect.x = rightRect.x - 10 - images[IMG_LEFT]->w;
-    leftRect.y = screen->h - images[IMG_LEFT]->h - 20;
-  }
-
-  /* Red "Stop" circle in upper right corner to go back to main menu: */
-  if (images[IMG_STOP])
-  {
-    stopRect.w = images[IMG_STOP]->w;
-    stopRect.h = images[IMG_STOP]->h;
-    stopRect.x = screen->w - images[IMG_STOP]->w;
-    stopRect.y = 0;
-  }
-
-  if (Tux && Tux->frame[0]) /* make sure sprite has at least one frame */
-   {
-    TuxRect.w = Tux->frame[0]->w;
-    TuxRect.h = Tux->frame[0]->h;
-    TuxRect.x = 0;
-    TuxRect.y = screen->h - Tux->frame[0]->h;
-   }
-
-
   while (!finished)
   {
     start = SDL_GetTicks();
 
     /* Check for user events: */
-    while (SDL_PollEvent(&event)) 
+    while (SDL_PollEvent(&event))
     {
       switch (event.type)
       {
@@ -116,15 +78,15 @@ void DisplayHighScores(int level)
 
         case SDL_MOUSEBUTTONDOWN:
         /* "Stop" button - go to main menu: */
-        { 
-          if (inRect(stopRect, event.button.x, event.button.y ))
+        {
+          if (inRect(stop_rect, event.button.x, event.button.y ))
           {
             finished = 1;
             playsound(SND_TOCK);
           }
 
           /* "Left" button - go to previous page: */
-          if (inRect(leftRect, event.button.x, event.button.y))
+          if (inRect(prev_rect, event.button.x, event.button.y))
           {
             if (diff_level > CADET_HIGH_SCORE)
             {
@@ -137,7 +99,7 @@ void DisplayHighScores(int level)
           }
 
           /* "Right" button - go to next page: */
-          if (inRect( rightRect, event.button.x, event.button.y ))
+          if (inRect(next_rect, event.button.x, event.button.y ))
           {
             if (diff_level < (NUM_HIGH_SCORE_LEVELS-1))
             {
@@ -164,37 +126,31 @@ void DisplayHighScores(int level)
     /* If needed, redraw: */
     if (diff_level != old_diff_level)
     {
-      /* Draw background: */
-      if (current_bkg())
-        SDL_BlitSurface( current_bkg(), NULL, screen, NULL );
-      /* FIXME maybe add image of trophy or similar pic */
-      /* Draw Tux: */
-      if (Tux && Tux->frame[0]) /* make sure sprite has at least one frame */
-        SDL_BlitSurface(Tux->frame[0], NULL, screen, &TuxRect);
+      DrawTitleScreen();
       /* Draw controls: */
-      if (images[IMG_STOP])
-        SDL_BlitSurface(images[IMG_STOP], NULL, screen, &stopRect);
+      if (stop_button)
+        SDL_BlitSurface(stop_button, NULL, screen, &stop_rect);
       /* Draw regular or grayed-out left arrow: */
       if (diff_level == CADET_HIGH_SCORE)
       {
-        if (images[IMG_LEFT_GRAY])
-          SDL_BlitSurface(images[IMG_LEFT_GRAY], NULL, screen, &leftRect);
+        if (prev_gray)
+          SDL_BlitSurface(prev_gray, NULL, screen, &prev_rect);
       }
       else
       {
-        if (images[IMG_LEFT])
-          SDL_BlitSurface(images[IMG_LEFT], NULL, screen, &leftRect);
+        if (prev_arrow)
+          SDL_BlitSurface(prev_arrow, NULL, screen, &prev_rect);
       }
       /* Draw regular or grayed-out right arrow: */
       if (diff_level == NUM_HIGH_SCORE_LEVELS - 1)
       {
-        if (images[IMG_RIGHT_GRAY])
-          SDL_BlitSurface(images[IMG_RIGHT_GRAY], NULL, screen, &rightRect);
+        if (next_gray)
+          SDL_BlitSurface(next_gray, NULL, screen, &next_rect);
       }
       else
       {
-        if (images[IMG_RIGHT])
-          SDL_BlitSurface(images[IMG_RIGHT], NULL, screen, &rightRect);
+        if (next_arrow)
+          SDL_BlitSurface(next_arrow, NULL, screen, &next_rect);
       }
 
       /* Draw background shading for table: */
@@ -282,7 +238,6 @@ void DisplayHighScores(int level)
         /* Clear out old surfaces and update: */
         if (score_surfs[i])               /* this should not happen! */
           SDL_FreeSurface(score_surfs[i]);
-        
         if (HS_Score(diff_level, i) == Opts_LastScore() && frame % 5 < 2)
           score_surfs[i] = BlackOutline(N_(score_strings[i]), player_font_size, &yellow);
         else
@@ -291,7 +246,6 @@ void DisplayHighScores(int level)
         /* Get out if BlackOutline() fails: */
         if (!score_surfs[i])
           continue;
-         
         /* Set up entries in vertical column: */
         if (0 == i)
           score_rects[i].y = score_table_y;
@@ -312,25 +266,7 @@ void DisplayHighScores(int level)
       old_diff_level = diff_level;
     }
 
-
-    /* --- make tux blink --- */
-    switch (frame % TUX6)
-    {
-      case 0:    tux_frame = 1; break;
-      case TUX1: tux_frame = 2; break;
-      case TUX2: tux_frame = 3; break;
-      case TUX3: tux_frame = 4; break;                        
-      case TUX4: tux_frame = 3; break;
-      case TUX5: tux_frame = 2; break;
-      default: tux_frame = 0;
-    }
-
-    if (Tux && tux_frame)
-    {
-      SDL_BlitSurface(Tux->frame[tux_frame - 1], NULL, screen, &TuxRect);
-      SDL_UpdateRect(screen, TuxRect.x, TuxRect.y, TuxRect.w, TuxRect.h);
-    }
-
+    HandleTitleScreenAnimations();
 
     /* Wait so we keep frame rate constant: */
     while ((SDL_GetTicks() - start) < 33)
@@ -339,8 +275,6 @@ void DisplayHighScores(int level)
     }
     frame++;
   }  // End of while (!finished) loop
-
-  FreeSprite(Tux);
 }
 
 
@@ -359,13 +293,10 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
 
   SDL_Rect loc;
   SDL_Rect redraw_rect;
-  SDL_Rect TuxRect,
-           stopRect;
 
   int redraw = 0;
   int first_draw = 1;
   int finished = 0;
-  int tux_frame = 0;
   Uint32 frame = 0;
   Uint32 start = 0;
   wchar_t wchar_buf[HIGH_SCORE_NAME_LENGTH + 1] = {'\0'};
@@ -374,40 +305,20 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
   const int BG_WIDTH = 400;
   const int BG_HEIGHT = 200;
 
-  sprite* Tux = LoadSprite("tux/bigtux", IMG_ALPHA);
-
   if (!pl_name)
     return;
-    
 
   /* We need to get Unicode vals from SDL keysyms */
   SDL_EnableUNICODE(SDL_ENABLE);
 
-#ifdef TUXMATH_DEBUG
-  fprintf(stderr, "\nEnter HighScoreNameEntry()\n" );
-#endif
+  DEBUGMSG(debug_highscore, "Enter HighScoreNameEntry()\n" );
 
-
-  /* Draw background: */
-  if (current_bkg())
-    SDL_BlitSurface(current_bkg(), NULL, screen, NULL);
+  DrawTitleScreen();
 
   /* Red "Stop" circle in upper right corner to go back to main menu: */
-  if (images[IMG_STOP])
+  if (stop_button)
   {
-    stopRect.w = images[IMG_STOP]->w;
-    stopRect.h = images[IMG_STOP]->h;
-    stopRect.x = screen->w - images[IMG_STOP]->w;
-    stopRect.y = 0;
-    SDL_BlitSurface(images[IMG_STOP], NULL, screen, &stopRect);
-  }
-
-  if (Tux && Tux->frame[0]) /* make sure sprite has at least one frame */
-  {
-    TuxRect.w = Tux->frame[0]->w;
-    TuxRect.h = Tux->frame[0]->h;
-    TuxRect.x = 0;
-    TuxRect.y = screen->h - Tux->frame[0]->h;
+    SDL_BlitSurface(stop_button, NULL, screen, &stop_rect);
   }
 
   /* Draw translucent background for text: */
@@ -453,12 +364,11 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
   SDL_UpdateRect(screen, 0, 0, 0, 0);
 
 
-
   while (!finished)
   {
     start = SDL_GetTicks();
 
-    while (SDL_PollEvent(&event)) 
+    while (SDL_PollEvent(&event))
     {
       switch (event.type)
       {
@@ -469,8 +379,8 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
 
         case SDL_MOUSEBUTTONDOWN:
         /* "Stop" button - go to main menu: */
-        { 
-          if (inRect(stopRect, event.button.x, event.button.y ))
+        {
+          if (inRect(stop_rect, event.button.x, event.button.y ))
           {
             finished = 1;
             playsound(SND_TOCK);
@@ -479,10 +389,8 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
         }
         case SDL_KEYDOWN:
         {
-#ifdef TUXMATH_DEBUG
-          fprintf(stderr, "Before keypress, string is %S\tlength = %d\n",
-                  wchar_buf, (int)wcslen(wchar_buf));
-#endif
+          DEBUGMSG(debug_highscore, "Before keypress, string is %S\tlength = %d\n",
+                   wchar_buf, (int)wcslen(wchar_buf));
           switch (event.key.keysym.sym)
           {
             case SDLK_ESCAPE:
@@ -510,14 +418,12 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
               {
                 wchar_buf[(int)wcslen(wchar_buf)] = event.key.keysym.unicode;
                 redraw = 1;
-              } 
+              }
             }
           }  /* end  'switch (event.key.keysym.sym)'  */
 
-#ifdef TUXMATH_DEBUG
-          fprintf(stderr, "After keypress, string is %S\tlength = %d\n",
-                    wchar_buf, (int)wcslen(wchar_buf));
-#endif
+          DEBUGMSG(debug_highscore, "After keypress, string is %S\tlength = %d\n",
+                   wchar_buf, (int)wcslen(wchar_buf));
             /* Now draw name, if needed: */
           if (redraw)
           {
@@ -567,24 +473,8 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
         }
       }
     }
- 
-    /* --- make tux blink --- */
-    switch (frame % TUX6)
-    {
-      case 0:    tux_frame = 1; break;
-      case TUX1: tux_frame = 2; break;
-      case TUX2: tux_frame = 3; break;
-      case TUX3: tux_frame = 4; break;                        
-      case TUX4: tux_frame = 3; break;
-      case TUX5: tux_frame = 2; break;
-      default: tux_frame = 0;
-    }
 
-    if (Tux && tux_frame)
-    {
-      SDL_BlitSurface(Tux->frame[tux_frame - 1], NULL, screen, &TuxRect);
-      SDL_UpdateRect(screen, TuxRect.x, TuxRect.y, TuxRect.w, TuxRect.h);
-    }
+    HandleTitleScreenAnimations();
 
     /* Wait so we keep frame rate constant: */
     while ((SDL_GetTicks() - start) < 33)
@@ -594,13 +484,11 @@ void NameEntry(char* pl_name, const char* heading, const char* sub)
     frame++;
   }  // End of while (!finished) loop
 
-  FreeSprite(Tux);
-
   /* Turn off SDL Unicode lookup (because has some overhead): */
   SDL_EnableUNICODE(SDL_DISABLE);
 
   /* Now copy name into location pointed to by arg: */ 
-  strncpy((char*)pl_name, (char*)UTF8_buf, HIGH_SCORE_NAME_LENGTH * 3);
+  strncpy(pl_name, UTF8_buf, HIGH_SCORE_NAME_LENGTH * 3);
 }
 
 
@@ -747,10 +635,7 @@ int read_high_scores_fp(FILE* fp)
   int score_read;
   int diff_level;
 
-
-#ifdef TUXMATH_DEBUG
-  printf("\nEntering read_high_scores_fp()\n");
-#endif
+  DEBUGMSG(debug_highscore, "Entering read_high_scores_fp()\n");
 
   /* get out if file pointer invalid: */
   if(!fp)
@@ -838,3 +723,450 @@ char* HS_Name(int diff_level, int place)
 
   return high_scores[diff_level][place].name;
 }
+
+
+int Ready(const char* heading)
+{
+  SDL_Rect loc;
+  SDL_Rect okRect;
+  int finished = 0;
+  Uint32 frame = 0;
+  Uint32 timer = 0;
+  const int BG_Y = 100;
+  const int BG_WIDTH = 400;
+  const int BG_HEIGHT = 200;
+
+  DEBUGMSG(debug_highscore, "Enter Ready()\n" );
+
+  DrawTitleScreen();
+
+  /* Draw translucent background for text: */
+  {
+    SDL_Rect bg_rect;
+    bg_rect.x = (screen->w)/2 - BG_WIDTH/2;
+    bg_rect.y = BG_Y;
+    bg_rect.w = BG_WIDTH;
+    bg_rect.h = BG_HEIGHT;
+    DrawButton(&bg_rect, 15, REG_RGBA);
+
+    bg_rect.x += 10;
+    bg_rect.y += 10;
+    bg_rect.w -= 20;
+    bg_rect.h = 60;
+    DrawButton(&bg_rect, 10, SEL_RGBA);
+  }
+
+  /* Draw heading: */
+  {
+    SDL_Surface* s = BlackOutline(_(heading),
+                                  DEFAULT_MENU_FONT_SIZE, &white);
+    if (s)
+    {
+      loc.x = (screen->w/2) - (s->w/2);
+      loc.y = 110;
+      SDL_BlitSurface(s, NULL, screen, &loc);
+      SDL_FreeSurface(s);
+    }
+  }
+
+  /* Red "Stop" circle in upper right corner to go back to main menu: */
+  if (stop_button)
+  {
+    SDL_BlitSurface(stop_button, NULL, screen, &stop_rect);
+  }
+
+  /* "Next_arrow" to indicate ready to proceed: */
+  if (next_arrow)
+  {
+    okRect.x = (screen->w)/2;
+    okRect.y = 240;
+    SDL_BlitSurface(next_arrow, NULL, screen, &okRect);
+  }
+
+  /* and update: */
+  SDL_UpdateRect(screen, 0, 0, 0, 0);
+
+
+  while (!finished)
+  {
+    /* Handle user events: */
+    while (SDL_PollEvent(&event))
+    {
+      switch (event.type)
+      {
+        case SDL_QUIT:
+        {
+          cleanup();
+        }
+
+        case SDL_MOUSEBUTTONDOWN:
+        /* "Stop" button - go to main menu: */
+        {
+          if (inRect(stop_rect, event.button.x, event.button.y ))
+          {
+            finished = -1;
+            playsound(SND_TOCK);
+            break;
+          } 
+          else if (inRect(okRect, event.button.x, event.button.y ))
+          {
+            finished = 1;
+            playsound(SND_TOCK);
+            break;
+          }
+
+        }
+        case SDL_KEYDOWN:
+        {
+          switch (event.key.keysym.sym)
+          {
+            case SDLK_ESCAPE:
+            case SDLK_BACKSPACE:
+            {
+              finished = -2;
+              playsound(SND_TOCK);
+              break;
+            }
+            case SDLK_RETURN:
+            case SDLK_KP_ENTER:
+            case SDLK_SPACE:
+            {
+              finished = 1;
+              playsound(SND_TOCK);
+              break;
+            }
+            default:
+            {
+              //Do nothing - event. add support for toggle fullscreen, etc.
+            }
+          } 
+        }
+      }
+    }
+
+    HandleTitleScreenAnimations();
+    Throttle(20, &timer);
+    frame++;
+  }  // End of while (!finished) loop
+
+  DEBUGMSG(debug_highscore, "Leave Ready()\n" );
+
+  /* 1 means we start game, -1 means we go back to menu */
+  return finished;
+}
+
+
+int Standby(const char* heading, const char* sub)
+{
+#ifndef HAVE_LIBSDL_NET
+  return 0;
+#else
+  SDL_Rect loc;
+  int finished = 0;
+  Uint32 frame = 0;
+  Uint32 timer = 0;
+  const int BG_Y = 100;
+  const int BG_WIDTH = 400;
+  const int BG_HEIGHT = 200;
+
+  char buf[NET_BUF_LEN];
+
+  DEBUGMSG(debug_highscore, "Enter Standby()\n" );
+
+  DrawTitleScreen();
+
+  /* Draw translucent background for text: */
+  {
+    SDL_Rect bg_rect;
+    bg_rect.x = (screen->w)/2 - BG_WIDTH/2;
+    bg_rect.y = BG_Y;
+    bg_rect.w = BG_WIDTH;
+    bg_rect.h = BG_HEIGHT;
+    DrawButton(&bg_rect, 15, REG_RGBA);
+
+    bg_rect.x += 10;
+    bg_rect.y += 10;
+    bg_rect.w -= 20;
+    bg_rect.h = 60;
+    DrawButton(&bg_rect, 10, SEL_RGBA);
+  }
+
+  /* Draw heading: */
+  {
+    SDL_Surface* s = BlackOutline(_(heading),
+                                  DEFAULT_MENU_FONT_SIZE, &white);
+    if (s)
+    {
+      loc.x = (screen->w/2) - (s->w/2);
+      loc.y = 110;
+      SDL_BlitSurface(s, NULL, screen, &loc);
+      SDL_FreeSurface(s);
+    }
+
+    s = BlackOutline(_(sub),
+                     DEFAULT_MENU_FONT_SIZE, &white);
+    if (s)
+    {
+      loc.x = (screen->w/2) - (s->w/2);
+      loc.y = 140;
+      SDL_BlitSurface(s, NULL, screen, &loc);
+      SDL_FreeSurface(s);
+    }
+  }
+
+  /* Red "Stop" circle in upper right corner to go back to main menu: */
+  if (stop_button)
+  {
+    SDL_BlitSurface(stop_button, NULL, screen, &stop_rect);
+  }
+
+  /* and update: */
+  SDL_UpdateRect(screen, 0, 0, 0, 0);
+
+
+  while (!finished)
+  {
+    /* Handle user events: */
+    while (SDL_PollEvent(&event))
+    {
+      switch (event.type)
+      {
+        case SDL_QUIT:
+        {
+          cleanup();
+        }
+
+        case SDL_MOUSEBUTTONDOWN:
+        /* "Stop" button - go to main menu: */
+        {
+          if (inRect(stop_rect, event.button.x, event.button.y ))
+          {
+            finished = 1;
+            playsound(SND_TOCK);
+            break;
+          }
+        }
+        case SDL_KEYDOWN:
+        {
+          switch (event.key.keysym.sym)
+          {
+            case SDLK_ESCAPE:
+            case SDLK_BACKSPACE:
+            {
+              finished = -2;
+              playsound(SND_TOCK);
+              break;
+            }
+
+            default:
+            {
+              //Do nothing - event. add support for toggle fullscreen, etc.
+            }
+          } 
+        }
+      }
+    }
+
+    /* Handle server messages: */
+    while(!check_messages(buf))
+    {
+      if(strncmp(buf,"GO_TO_GAME", strlen("GO_TO_GAME")) == 0)
+      {
+        finished = 1;
+        playsound(SND_TOCK);
+        break;
+      }
+      else if(strncmp(buf, "GAME_IN_PROGRESS", strlen("GAME_IN_PROGRESS")) == 0)
+      {
+        finished = -1;
+        playsound(SND_TOCK);
+        break;
+      }
+      else
+      {
+        DEBUGMSG(debug_highscore, "Unrecognized message from server: %s\n", buf);
+        continue;
+      }
+    }
+
+    HandleTitleScreenAnimations();
+    Throttle(20, &timer);
+    frame++;
+  }  // End of while (!finished) loop
+
+  DEBUGMSG(debug_highscore, "Leave Standby()\n" );
+
+  /* 1 means we start game, -1 means we go back to menu */
+  return finished;
+#endif
+}
+
+
+
+int detecting_servers(const char* heading, const char* sub)
+{
+#ifndef HAVE_LIBSDL_NET
+  return 0;
+#else
+  SDL_Rect loc;
+  SDL_Rect TuxRect,
+           stopRect;
+
+  int finished = 0;
+  int tux_frame = 0;
+  Uint32 frame = 0;
+  Uint32 start = 0;
+  Uint32 timer = 0;
+  int servers_found = 0;  
+  sprite* Tux = NULL;
+
+  DEBUGMSG(debug_lan, "\nEnter detecting_servers()\n");
+
+  /* FIXME it takes several seconds to load this sprite on a */
+  /* Dell Mini 9 netbook, probably longer on many school     */
+  /* machines.  Perhaps we should load this ahead of time... */
+  Tux = LoadSprite("tux/bigtux", IMG_ALPHA);
+
+  /* We need to get Unicode vals from SDL keysyms */
+  SDL_EnableUNICODE(SDL_ENABLE);
+
+  /* Draw background: */
+  if (current_bkg())
+    SDL_BlitSurface(current_bkg(), NULL, screen, NULL);
+
+  /* Red "Stop" circle in upper right corner to go back to main menu: */
+  if (images[IMG_STOP])
+  {
+    stopRect.w = images[IMG_STOP]->w;
+    stopRect.h = images[IMG_STOP]->h;
+    stopRect.x = screen->w - images[IMG_STOP]->w;
+    stopRect.y = 0;
+    SDL_BlitSurface(images[IMG_STOP], NULL, screen, &stopRect);
+  }
+
+  if (Tux && Tux->frame[0]) /* make sure sprite has at least one frame */
+  {
+    TuxRect.w = Tux->frame[0]->w;
+    TuxRect.h = Tux->frame[0]->h;
+    TuxRect.x = 0;
+    TuxRect.y = screen->h - Tux->frame[0]->h;
+  }
+
+  /* Draw heading: */
+  {
+    SDL_Surface* s = BlackOutline(_(heading),
+                                  DEFAULT_MENU_FONT_SIZE, &white);
+    if (s)
+    {
+      loc.x = (screen->w/2) - (s->w/2);
+      loc.y = 110;
+      SDL_BlitSurface(s, NULL, screen, &loc);
+      SDL_FreeSurface(s);
+    }
+
+    s = BlackOutline(_(sub),
+                     DEFAULT_MENU_FONT_SIZE, &white);
+    if (s)
+    {
+      loc.x = (screen->w/2) - (s->w/2);
+      loc.y = 140;
+      SDL_BlitSurface(s, NULL, screen, &loc);
+      SDL_FreeSurface(s);
+    }
+  }
+
+  /* and update: */
+  SDL_UpdateRect(screen, 0, 0, 0, 0);
+
+  while (!finished)
+  {
+    start = SDL_GetTicks();
+
+    //Scan local network to find running server:
+    servers_found = LAN_DetectServers();
+    if(servers_found < 1)
+    {
+      printf("No server could be found - returning.\n");
+      /* Turn off SDL Unicode lookup (because has some overhead): */
+      SDL_EnableUNICODE(SDL_DISABLE);
+      FreeSprite(Tux);
+      return 0;
+    }
+    else if(servers_found  == 1)  //One server - connect without player intervention
+    {
+      printf("Single server found - connecting automatically...");
+
+      if(!LAN_AutoSetup(0))  //i.e.first (and only) entry in list
+      {
+        printf("LAN_AutoSetup() failed - returning.\n");
+        /* Turn off SDL Unicode lookup (because has some overhead): */
+        SDL_EnableUNICODE(SDL_DISABLE);
+        FreeSprite(Tux);
+        return 0;
+      }
+      
+      
+      finished = 1;
+      break;  //So we quit scanning as soon as we connect
+      printf("connected\n");
+    } else if (servers_found  > 1)
+    {
+      //TODO display list of servers for player to choose from:
+    }
+
+
+    while (SDL_PollEvent(&event)) 
+    {
+      switch (event.type)
+      {
+        case SDL_QUIT:
+        {
+          cleanup();
+        }
+
+        case SDL_MOUSEBUTTONDOWN:
+        /* "Stop" button - go to main menu: */
+        { 
+          if (inRect(stopRect, event.button.x, event.button.y ))
+          {
+            finished = 1;
+            playsound(SND_TOCK);
+            break;
+          }
+        }
+      }
+    }
+
+    /* --- make tux blink --- */
+    switch (frame % TUX6)
+    {
+      case 0:    tux_frame = 1; break;
+      case TUX1: tux_frame = 2; break;
+      case TUX2: tux_frame = 3; break;
+      case TUX3: tux_frame = 4; break;                        
+      case TUX4: tux_frame = 3; break;
+      case TUX5: tux_frame = 2; break;
+      default: tux_frame = 0;
+    }
+
+    if (Tux && tux_frame)
+    {
+      SDL_BlitSurface(Tux->frame[tux_frame - 1], NULL, screen, &TuxRect);
+      SDL_UpdateRect(screen, TuxRect.x, TuxRect.y, TuxRect.w, TuxRect.h);
+    }
+
+    /* Wait so we keep frame rate constant: */
+    Throttle(20, &timer);
+    frame++;
+  }  // End of while (!finished) loop
+
+
+  /* Turn off SDL Unicode lookup (because has some overhead): */
+  SDL_EnableUNICODE(SDL_DISABLE);
+  FreeSprite(Tux);
+
+  return 1;
+
+#endif
+}
+
