@@ -4,7 +4,7 @@
 // Description: 
 //
 //
-// Author: David Bruce <dbruce@tampabay.rr.com>, (C) 2007
+// Author: David Bruce <davidstuartbruce@gmail.com>, (C) 2007
 //
 // Copyright: See COPYING file that comes with this distribution
 // (Briefly, GNU GPL version 2 or greater).
@@ -16,9 +16,15 @@
 
 #include "globals.h"
 
+
 void DisplayHighScores(int level);
 void HighScoreNameEntry(char* pl_name);
 void NameEntry(char* pl_name, const char* heading, const char* sub);
+/* FIXME the next three don't have anything to do with high scores */
+/* and don't really belong here:                                   */
+int Standby(const char* heading, const char* sub);
+int detecting_servers(const char* heading, const char* sub);
+int Ready(const char* heading);
 
 int check_score_place(int diff_level, int new_score);
 int insert_score(char* playername, int diff_level, int new_score);
